@@ -213,7 +213,7 @@ process_tag (const GstTagList *list, const gchar *tag, RBPlayerGst *player)
 	GValue value = {0,};
 
 	/* process embedded images */
-	if (!strcmp (tag, GST_TAG_IMAGE) || !strcmp (tag, GST_TAG_PREVIEW_IMAGE)) {
+	if (!g_strcmp0 (tag, GST_TAG_IMAGE) || !g_strcmp0 (tag, GST_TAG_PREVIEW_IMAGE)) {
 		GdkPixbuf *pixbuf;
 		pixbuf = rb_gst_process_embedded_image (list, tag);
 		if (pixbuf != NULL) {
@@ -477,7 +477,7 @@ bus_cb (GstBus *bus, GstMessage *message, RBPlayerGst *mp)
 	switch (GST_MESSAGE_TYPE (message)) {
 	case GST_MESSAGE_ERROR: {
 		char *debug;
-		GError *error;
+		GError *error = NULL;
 		GError *sig_error = NULL;
 		int code;
 		gboolean emit = TRUE;
@@ -494,13 +494,7 @@ bus_cb (GstBus *bus, GstMessage *message, RBPlayerGst *mp)
 			emit = FALSE;
 		}
 
-		if ((error->domain == GST_CORE_ERROR)
-			|| (error->domain == GST_LIBRARY_ERROR)
-			|| (error->domain == GST_RESOURCE_ERROR && error->code == GST_RESOURCE_ERROR_BUSY)) {
-			code = RB_PLAYER_ERROR_NO_AUDIO;
-		} else {
-			code = RB_PLAYER_ERROR_GENERAL;
-		}
+		code = rb_gst_error_get_error_code (error);
 
 		if (emit) {
 			if (message_from_sink (mp->priv->audio_sink, message)) {
@@ -839,7 +833,6 @@ static gboolean
 impl_play (RBPlayer *player, RBPlayerPlayType play_type, gint64 crossfade, GError **error)
 {
 	RBPlayerGst *mp = RB_PLAYER_GST (player);
-	gboolean result;
 
 	g_return_val_if_fail (mp->priv->playbin != NULL, FALSE);
 
@@ -852,7 +845,6 @@ impl_play (RBPlayer *player, RBPlayerPlayType play_type, gint64 crossfade, GErro
 	} else if (mp->priv->current_track_finishing) {
 		rb_debug ("current track finishing -> just setting URI on playbin");
 		g_object_set (mp->priv->playbin, "uri", mp->priv->uri, NULL);
-		result = TRUE;
 
 		mp->priv->playbin_stream_changing = TRUE;
 
@@ -872,7 +864,6 @@ impl_play (RBPlayer *player, RBPlayerPlayType play_type, gint64 crossfade, GErro
 				g_signal_emit (player,
 					       signals[REUSE_STREAM], 0,
 					       mp->priv->uri, mp->priv->prev_uri, mp->priv->playbin);
-				result = TRUE;
 				track_change_done (mp, *error);
 			}
 		}
@@ -885,7 +876,7 @@ impl_play (RBPlayer *player, RBPlayerPlayType play_type, gint64 crossfade, GErro
 
 	}
 
-	return result;
+	return TRUE;
 }
 
 static void
